=begin
PureCloud Platform API

With the PureCloud Platform API, you can control all aspects of your PureCloud environment. With the APIs you can access the system configuration, manage conversations and more.

OpenAPI spec version: v2
Contact: DeveloperEvangelists@inin.com
Generated by: https://github.com/swagger-api/swagger-codegen.git

License: ININ
http://www.inin.com

Terms of Service: https://developer.mypurecloud.com/tos

=end

require 'date'

module PureCloud
  class Email
    # The connection state of this communication.
    attr_accessor :state

    # A globally unique identifier for this communication.
    attr_accessor :id

    # True if this call is held and the person on this side hears silence.
    attr_accessor :held

    # The subject for the initial email that started this conversation.
    attr_accessor :subject

    # The number of email messages sent by this participant.
    attr_accessor :messages_sent

    # The time line of the participant's email, divided into activity segments.
    attr_accessor :segments

    # The direction of the email
    attr_accessor :direction

    # A globally unique identifier for the recording associated with this call.
    attr_accessor :recording_id

    attr_accessor :error_info

    # System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.
    attr_accessor :disconnect_type

    # The timestamp the email was placed on hold in the cloud clock if the email is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
    attr_accessor :start_hold_time

    # The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
    attr_accessor :connected_time

    # The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
    attr_accessor :disconnected_time

    # The source provider for the email.
    attr_accessor :provider

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        
        :'state' => :'state',
        
        :'id' => :'id',
        
        :'held' => :'held',
        
        :'subject' => :'subject',
        
        :'messages_sent' => :'messagesSent',
        
        :'segments' => :'segments',
        
        :'direction' => :'direction',
        
        :'recording_id' => :'recordingId',
        
        :'error_info' => :'errorInfo',
        
        :'disconnect_type' => :'disconnectType',
        
        :'start_hold_time' => :'startHoldTime',
        
        :'connected_time' => :'connectedTime',
        
        :'disconnected_time' => :'disconnectedTime',
        
        :'provider' => :'provider'
        
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        :'state' => :'String',
        :'id' => :'String',
        :'held' => :'BOOLEAN',
        :'subject' => :'String',
        :'messages_sent' => :'Integer',
        :'segments' => :'Array<Segment>',
        :'direction' => :'String',
        :'recording_id' => :'String',
        :'error_info' => :'ErrorBody',
        :'disconnect_type' => :'String',
        :'start_hold_time' => :'DateTime',
        :'connected_time' => :'DateTime',
        :'disconnected_time' => :'DateTime',
        :'provider' => :'String'
        
      }
    end

    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

      
      if attributes[:'state']
        self.state = attributes[:'state']
      end
      
      if attributes[:'id']
        self.id = attributes[:'id']
      end
      
      if attributes[:'held']
        self.held = attributes[:'held']
      end
      
      if attributes[:'subject']
        self.subject = attributes[:'subject']
      end
      
      if attributes[:'messagesSent']
        self.messages_sent = attributes[:'messagesSent']
      end
      
      if attributes[:'segments']
        if (value = attributes[:'segments']).is_a?(Array)
          self.segments = value
        end
      end
      
      if attributes[:'direction']
        self.direction = attributes[:'direction']
      end
      
      if attributes[:'recordingId']
        self.recording_id = attributes[:'recordingId']
      end
      
      if attributes[:'errorInfo']
        self.error_info = attributes[:'errorInfo']
      end
      
      if attributes[:'disconnectType']
        self.disconnect_type = attributes[:'disconnectType']
      end
      
      if attributes[:'startHoldTime']
        self.start_hold_time = attributes[:'startHoldTime']
      end
      
      if attributes[:'connectedTime']
        self.connected_time = attributes[:'connectedTime']
      end
      
      if attributes[:'disconnectedTime']
        self.disconnected_time = attributes[:'disconnectedTime']
      end
      
      if attributes[:'provider']
        self.provider = attributes[:'provider']
      end
      
    end

    # Custom attribute writer method checking allowed values (enum).
    def state=(state)
      allowed_values = ["alerting", "connected", "disconnected", "none"]
      if state && !allowed_values.include?(state)
        fail "invalid value for 'state', must be one of #{allowed_values}"
      end
      @state = state
    end

    # Custom attribute writer method checking allowed values (enum).
    def direction=(direction)
      allowed_values = ["inbound", "outbound"]
      if direction && !allowed_values.include?(direction)
        fail "invalid value for 'direction', must be one of #{allowed_values}"
      end
      @direction = direction
    end

    # Custom attribute writer method checking allowed values (enum).
    def disconnect_type=(disconnect_type)
      allowed_values = ["endpoint", "client", "system", "timeout", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
      if disconnect_type && !allowed_values.include?(disconnect_type)
        fail "invalid value for 'disconnect_type', must be one of #{allowed_values}"
      end
      @disconnect_type = disconnect_type
    end

    # Check equality by comparing each attribute.
    def ==(o)
      return true if self.equal?(o)
      self.class == o.class &&
          state == o.state &&
          id == o.id &&
          held == o.held &&
          subject == o.subject &&
          messages_sent == o.messages_sent &&
          segments == o.segments &&
          direction == o.direction &&
          recording_id == o.recording_id &&
          error_info == o.error_info &&
          disconnect_type == o.disconnect_type &&
          start_hold_time == o.start_hold_time &&
          connected_time == o.connected_time &&
          disconnected_time == o.disconnected_time &&
          provider == o.provider
    end

    # @see the `==` method
    def eql?(o)
      self == o
    end

    # Calculate hash code according to all attributes.
    def hash
      [state, id, held, subject, messages_sent, segments, direction, recording_id, error_info, disconnect_type, start_hold_time, connected_time, disconnected_time, provider].hash
    end

    # build the object from hash
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)
      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
          else
            #TODO show warning in debug mode
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
        else
          # data not found in attributes(hash), not an issue as the data can be optional
        end
      end

      self
    end

    def _deserialize(type, value)
      case type.to_sym
      when :DateTime
        DateTime.parse(value)
      when :Date
        Date.parse(value)
      when :String
        value.to_s
      when :Integer
        value.to_i
      when :Float
        value.to_f
      when :BOOLEAN
        if value.to_s =~ /^(true|t|yes|y|1)$/i
          true
        else
          false
        end
      when :Object
        # generic object (usually a Hash), return directly
        value
      when /\AArray<(?<inner_type>.+)>\z/
        inner_type = Regexp.last_match[:inner_type]
        value.map { |v| _deserialize(inner_type, v) }
      when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
        k_type = Regexp.last_match[:k_type]
        v_type = Regexp.last_match[:v_type]
        {}.tap do |hash|
          value.each do |k, v|
            hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
          end
        end
      else # model
        _model = Object.const_get("PureCloud").const_get(type).new
        _model.build_from_hash(value)
      end
    end

    def to_s
      to_hash.to_s
    end

    # to_body is an alias to to_body (backward compatibility))
    def to_body
      to_hash
    end

    # return the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = self.send(attr)
        next if value.nil?
        hash[param] = _to_hash(value)
      end
      hash
    end

    # Method to output non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map{ |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end

  end
end
