=begin
PureCloud Platform API

With the PureCloud Platform API, you can control all aspects of your PureCloud environment. With the APIs you can access the system configuration, manage conversations and more.

OpenAPI spec version: v2
Contact: DeveloperEvangelists@inin.com
Generated by: https://github.com/swagger-api/swagger-codegen.git

License: ININ
http://www.inin.com

Terms of Service: https://developer.mypurecloud.com/tos

=end

require 'date'

module PureCloud
  # Contains information about a response.
  class Response
    # The globally unique identifier for the object.
    attr_accessor :id

    attr_accessor :name

    # Version number required for updates.
    attr_accessor :version

    # One or more libraries response is associated with.
    attr_accessor :libraries

    # One or more texts associated with the response.
    attr_accessor :texts

    # User that created the response
    attr_accessor :created_by

    # The date and time the response was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
    attr_accessor :date_created

    # The interaction type for this response.
    attr_accessor :interaction_type

    # Details about any text substitutions used in the texts for this response.
    attr_accessor :substitutions

    # The URI for this object
    attr_accessor :self_uri

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        
        :'id' => :'id',
        
        :'name' => :'name',
        
        :'version' => :'version',
        
        :'libraries' => :'libraries',
        
        :'texts' => :'texts',
        
        :'created_by' => :'createdBy',
        
        :'date_created' => :'dateCreated',
        
        :'interaction_type' => :'interactionType',
        
        :'substitutions' => :'substitutions',
        
        :'self_uri' => :'selfUri'
        
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        :'id' => :'String',
        :'name' => :'String',
        :'version' => :'Integer',
        :'libraries' => :'Array<UriReference>',
        :'texts' => :'Array<ResponseText>',
        :'created_by' => :'User',
        :'date_created' => :'DateTime',
        :'interaction_type' => :'String',
        :'substitutions' => :'Array<ResponseSubstitution>',
        :'self_uri' => :'String'
        
      }
    end

    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.inject({}){|memo,(k,v)| memo[k.to_sym] = v; memo}

      
      if attributes[:'id']
        self.id = attributes[:'id']
      end
      
      if attributes[:'name']
        self.name = attributes[:'name']
      end
      
      if attributes[:'version']
        self.version = attributes[:'version']
      end
      
      if attributes[:'libraries']
        if (value = attributes[:'libraries']).is_a?(Array)
          self.libraries = value
        end
      end
      
      if attributes[:'texts']
        if (value = attributes[:'texts']).is_a?(Array)
          self.texts = value
        end
      end
      
      if attributes[:'createdBy']
        self.created_by = attributes[:'createdBy']
      end
      
      if attributes[:'dateCreated']
        self.date_created = attributes[:'dateCreated']
      end
      
      if attributes[:'interactionType']
        self.interaction_type = attributes[:'interactionType']
      end
      
      if attributes[:'substitutions']
        if (value = attributes[:'substitutions']).is_a?(Array)
          self.substitutions = value
        end
      end
      
      if attributes[:'selfUri']
        self.self_uri = attributes[:'selfUri']
      end
      
    end

    # Custom attribute writer method checking allowed values (enum).
    def interaction_type=(interaction_type)
      allowed_values = ["chat", "email", "twitter"]
      if interaction_type && !allowed_values.include?(interaction_type)
        fail "invalid value for 'interaction_type', must be one of #{allowed_values}"
      end
      @interaction_type = interaction_type
    end

    # Check equality by comparing each attribute.
    def ==(o)
      return true if self.equal?(o)
      self.class == o.class &&
          id == o.id &&
          name == o.name &&
          version == o.version &&
          libraries == o.libraries &&
          texts == o.texts &&
          created_by == o.created_by &&
          date_created == o.date_created &&
          interaction_type == o.interaction_type &&
          substitutions == o.substitutions &&
          self_uri == o.self_uri
    end

    # @see the `==` method
    def eql?(o)
      self == o
    end

    # Calculate hash code according to all attributes.
    def hash
      [id, name, version, libraries, texts, created_by, date_created, interaction_type, substitutions, self_uri].hash
    end

    # build the object from hash
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)
      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
          else
            #TODO show warning in debug mode
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
        else
          # data not found in attributes(hash), not an issue as the data can be optional
        end
      end

      self
    end

    def _deserialize(type, value)
      case type.to_sym
      when :DateTime
        DateTime.parse(value)
      when :Date
        Date.parse(value)
      when :String
        value.to_s
      when :Integer
        value.to_i
      when :Float
        value.to_f
      when :BOOLEAN
        if value.to_s =~ /^(true|t|yes|y|1)$/i
          true
        else
          false
        end
      when :Object
        # generic object (usually a Hash), return directly
        value
      when /\AArray<(?<inner_type>.+)>\z/
        inner_type = Regexp.last_match[:inner_type]
        value.map { |v| _deserialize(inner_type, v) }
      when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
        k_type = Regexp.last_match[:k_type]
        v_type = Regexp.last_match[:v_type]
        {}.tap do |hash|
          value.each do |k, v|
            hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
          end
        end
      else # model
        _model = Object.const_get("PureCloud").const_get(type).new
        _model.build_from_hash(value)
      end
    end

    def to_s
      to_hash.to_s
    end

    # to_body is an alias to to_body (backward compatibility))
    def to_body
      to_hash
    end

    # return the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = self.send(attr)
        next if value.nil?
        hash[param] = _to_hash(value)
      end
      hash
    end

    # Method to output non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map{ |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end

  end
end
